<html>
 <head>
  <meta http-equiv="Content-type" content="text/html; charset=utf-8">
  <title>Do Not Track</title>
 </head>
 <body>
  <p>Do Not Track: <code class="dnt">{{ request.DNT }}</code></p>
 </body>
</html>
